/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';

/// Define the switch provider state
class ZwapSwitchState extends ChangeNotifier {

  /// The value of this state
  bool value;

  ZwapSwitchState({required this.value});

  /// Change the state inside this switch
  void changeState(bool value) {
    this.value = value;
    notifyListeners();
  }
}

/// Custom widget to display a switch component
class ZwapSwitch extends StatelessWidget {
  /// It handles the change inside the switch state
  void handleChange(BuildContext context) {
    bool value = context.read<ZwapSwitchState>().value;
    context.read<ZwapSwitchState>().changeState(value);
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<ZwapSwitchState>(builder: (builder, provider, child) {
      return CupertinoSwitch(
        activeColor: ZwapColors.primary700,
        trackColor: ZwapColors.neutral200,
        value: provider.value,
        onChanged: (bool value) => provider.changeState(value),
      );
    });
  }
}
