/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';
import 'package:zwap_design_system/molecules/molecules.dart';

/// It handles the state provider for this tabBar
class ZwapSecondaryTabBarState extends ChangeNotifier {

  /// The items inside the tabBar menu
  final List<String> items;

  /// The current selected item
  late String currentSelected;

  /// The hoovered item
  String hooveredItem = "";

  ZwapSecondaryTabBarState({required this.items}) {
    assert(this.items.length == 2,
        "This type of tab bar must have a max of 2 items");
    this.currentSelected = this.items.first;
  }

  /// Handle change inside this tabBar items
  void onChange(String newKey) {
    this.currentSelected = newKey;
    notifyListeners();
  }

  /// It handles the hoovering on item inside the horizontal tabBar
  void onHover(String? newItem){
    if(newItem != null){
      this.hooveredItem = newItem;
    }
    else{
      this.hooveredItem = "";
    }
    notifyListeners();
  }
}

/// Widget to display a secondary tab bar
class ZwapSecondaryTabBar extends StatelessWidget {

  /// It builds the button widget inside this horizontal tabBar
  Widget _getButtonWidget(ZwapSecondaryTabBarState provider, int index){
    return Flexible(
      child: Padding(
        padding: EdgeInsets.all(4),
        child: MouseRegion(
          onExit: (_) => provider.onHover(null),
          onEnter: (_) => provider.onHover(provider.items[index]),
          child: ZwapButton(
            lateralPadding: 37,
            zwapButtonStatus: ZwapButtonStatus.defaultStatus,
            zwapButtonContentType: ZwapButtonContentType.noIcon,
            zwapButtonType: ZwapButtonType.secondary,
            text: provider.items[index],
            onPressedCallBack: () =>
                provider.onChange(provider.items[index]),
            textColor: provider.currentSelected == provider.items[index]
                ? ZwapColors.neutral700
                : provider.hooveredItem == provider.items[index] ? ZwapColors.neutral500 : ZwapColors.neutral400,
            buttonColor: provider.currentSelected == provider.items[index] ? ZwapColors.shades0 : ZwapColors.neutral200,
          ),
        ),
      ),
      flex: 0,
      fit: FlexFit.tight,
    );
  }


  @override
  Widget build(BuildContext context) {
    return Consumer<ZwapSecondaryTabBarState>(
        builder: (builder, provider, child) {
      return Container(
        height: 50,
        decoration: BoxDecoration(
            color: ZwapColors.neutral200,
            borderRadius: BorderRadius.all(Radius.circular(ZwapRadius.tabBarRadius))
        ),
        child: Padding(
          padding: EdgeInsets.all(ZwapRadius.defaultRadius),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              this._getButtonWidget(provider, 0),
              this._getButtonWidget(provider, 1),
            ],
          ),
        ),
      );
    });
  }
}
